@@ -3,7 +3,8 @@ import time
 import json
 from pathlib import Path
 from qualys_etl.etld_lib import etld_lib_config
-from qualys_etl.etld_lib import etld_lib_credentials
+#from qualys_etl.etld_lib import etld_lib_credentials
+from qualys_etl.etld_lib import etld_lib_authentication_objects
 from qualys_etl.etld_lib import etld_lib_functions
 from qualys_etl.etld_lib import etld_lib_datetime
 from qualys_etl.etld_lib import etld_lib_extract_transform_load
@@ -125,8 +126,10 @@ def get_asset_inventory_data():
     has_more_records = '1'
     batch_number = 0
     batch_number_str = f'batch_{batch_number:06d}'
-    cred_dict = etld_lib_credentials.get_cred(cred_dict={})
-    cred_dict = etld_lib_credentials.get_bearer_stored_in_env(update_bearer=False, cred=cred_dict)
+    #cred_dict = etld_lib_credentials.get_cred(cred_dict={})
+    #cred_dict = etld_lib_credentials.get_bearer_stored_in_env(update_bearer=False, cred=cred_dict)
+    etld_lib_authentication_objects.qualys_authentication_obj.get_current_bearer_token()
+    cred_dict = etld_lib_authentication_objects.qualys_authentication_obj.get_credentials_dict()
 
     file_info_dict = \
         etld_lib_config.prepare_extract_batch_file_name(
@@ -162,7 +165,9 @@ def get_asset_inventory_data():
                 file_extension="json",
                 compression_method=etld_lib_config.asset_inventory_open_file_compression_method)
 
-        cred_dict = etld_lib_credentials.get_bearer_stored_in_env(update_bearer=False, cred=cred_dict)
+        #cred_dict = etld_lib_credentials.get_bearer_stored_in_env(update_bearer=False, cred=cred_dict)
+        etld_lib_authentication_objects.qualys_authentication_obj.get_current_bearer_token()
+        cred_dict = etld_lib_authentication_objects.qualys_authentication_obj.get_credentials_dict()
 
         cred_dict = asset_inventory_04_extract_from_qualys.asset_inventory_extract(
             asset_last_updated=etld_lib_config.asset_inventory_asset_last_updated,
@@ -210,5 +215,6 @@ def main():
 if __name__ == "__main__":
     etld_lib_functions.main(my_logger_prog_name='asset_inventory_03_extract_controller')
     etld_lib_config.main()
-    etld_lib_credentials.main()
+    #etld_lib_credentials.main()
+    etld_lib_authentication_objects.main()
     main()
