@@ -22,6 +22,12 @@ def transform_epoch_dates(item):
     item['agent_lastInventoryDate'] = ""
     item['inventory_createdDate'] = ""
     item['inventory_lastUpdatedDate'] = ""
+    # Added 2022-12-16
+    item['sensor_lastPcScanDateAgent'] = ""
+    item['sensor_lastPcScanDateScanner'] = ""
+    item['sensor_lastVmScanDateAgent'] = ""
+    item['sensor_lastVmScanDateScanner'] = ""
+
     if 'sensor' in item.keys() and item['sensor'] is not None:
         if 'lastVMScan' in item['sensor']:
             item['sensor_lastVMScanDate'] = \
@@ -32,6 +38,18 @@ def transform_epoch_dates(item):
         if 'lastFullScan' in item['sensor']:
             item['sensor_lastFullScanDate'] = \
                 etld_lib_datetime.get_datetime_str_from_epoch_milli_sec(item['sensor']['lastFullScan'])
+        if 'lastPcScanDateAgent' in item['sensor']:
+            item['sensor_lastPcScanDateAgent'] = \
+                etld_lib_datetime.get_datetime_str_from_epoch_milli_sec(item['sensor']['lastPcScanDateAgent'])
+        if 'lastPcScanDateScanner' in item['sensor']:
+            item['sensor_lastPcScanDateScanner'] = \
+                etld_lib_datetime.get_datetime_str_from_epoch_milli_sec(item['sensor']['lastPcScanDateScanner'])
+        if 'lastVmScanDateAgent' in item['sensor']:
+            item['sensor_lastVmScanDateAgent'] = \
+                etld_lib_datetime.get_datetime_str_from_epoch_milli_sec(item['sensor']['lastVmScanDateAgent'])
+        if 'lastVmScanDateScanner' in item['sensor']:
+            item['sensor_lastVmScanDateScanner'] = \
+                etld_lib_datetime.get_datetime_str_from_epoch_milli_sec(item['sensor']['lastVmScanDateScanner'])
 
     if 'agent' in item.keys() and item['agent'] is not None:
         if 'lastActivity' in item['agent']:
