@@ -4,7 +4,8 @@ import timeit
 from pathlib import Path
 from qualys_etl.etld_lib import etld_lib_functions
 from qualys_etl.etld_lib import etld_lib_config
-from qualys_etl.etld_lib import etld_lib_credentials
+#from qualys_etl.etld_lib import etld_lib_credentials
+from qualys_etl.etld_lib import etld_lib_authentication_objects
 
 from qualys_etl.etld_host_list import host_list_03_extract_controller
 from qualys_etl.etld_host_list import host_list_06_distribution
@@ -28,9 +29,6 @@ def host_list_06_distribution_wrapper(
 
 def begin_message_info():
     etld_lib_functions.logger.info(f"data directory: {etld_lib_config.qetl_user_data_dir}")
-    etld_lib_functions.logger.info(f"config file:    {etld_lib_config.qetl_user_config_settings_yaml_file}")
-    etld_lib_functions.logger.info(f"cred yaml file: {etld_lib_credentials.cred_file}")
-    etld_lib_functions.logger.info(f"cookie file:    {etld_lib_credentials.cookie_file}")
 
 
 def begin_host_list_02_workflow_manager():
@@ -85,5 +83,6 @@ def main():
 if __name__ == "__main__":
     etld_lib_functions.main(my_logger_prog_name='host_list_02_workflow_manager')
     etld_lib_config.main()
-    etld_lib_credentials.main()
+    #etld_lib_credentials.main()
+    etld_lib_authentication_objects.main()
     main()
