@@ -6,6 +6,7 @@ import re
 import xmltodict
 from qualys_etl.etld_lib import etld_lib_config
 from qualys_etl.etld_lib import etld_lib_credentials
+from qualys_etl.etld_lib import etld_lib_authentication_objects
 from qualys_etl.etld_lib import etld_lib_functions
 from qualys_etl.etld_lib import etld_lib_datetime
 from qualys_etl.etld_lib import etld_lib_extract_transform_load
@@ -152,7 +153,8 @@ def extract_host_list_data_from_qualys(cleanup_old_files=True):
     global counter_obj_dict
     begin_host_list_03_extract_controller()
     counter_obj_dict = create_counter_objects("hosts added to host_list_extract_dir")
-    cred_dict = etld_lib_credentials.get_cred(cred_dict={})
+    #cred_dict = etld_lib_credentials.get_cred(cred_dict={})
+    cred_dict = etld_lib_authentication_objects.qualys_authentication_obj.get_credentials_dict()
     utc_datetime = etld_lib_datetime.get_utc_datetime_qualys_format()
     batch_number = 0
     batch_date = utc_datetime
@@ -251,4 +253,5 @@ if __name__ == "__main__":
     etld_lib_functions.main(my_logger_prog_name='host_list_03_extract_controller')
     etld_lib_config.main()
     etld_lib_credentials.main()
+    etld_lib_authentication_objects.main()
     main()
