@@ -7,7 +7,8 @@ from pathlib import Path
 import multiprocessing
 from qualys_etl.etld_lib import etld_lib_functions
 from qualys_etl.etld_lib import etld_lib_config
-from qualys_etl.etld_lib import etld_lib_credentials
+#from qualys_etl.etld_lib import etld_lib_credentials
+from qualys_etl.etld_lib import etld_lib_authentication_objects
 
 from qualys_etl.etld_host_list_detection import host_list_detection_03_extract_controller
 from qualys_etl.etld_host_list_detection import host_list_detection_05_transform_load_xml_to_sqlite
@@ -55,8 +56,6 @@ def host_list_detection_06_distribution_wrapper(module_function=host_list_detect
 def begin_message_info():
     etld_lib_functions.logger.info(f"data directory: {etld_lib_config.qetl_user_data_dir}")
     etld_lib_functions.logger.info(f"config file:    {etld_lib_config.qetl_user_config_settings_yaml_file}")
-    etld_lib_functions.logger.info(f"cred yaml file: {etld_lib_credentials.cred_file}")
-    etld_lib_functions.logger.info(f"cookie file:    {etld_lib_credentials.cookie_file}")
 
 
 def begin_host_list_detection_02_workflow_manager():
@@ -75,15 +74,6 @@ def end_host_list_detection_02_workflow_manager():
     etld_lib_functions.logger.info(f"__end__ host_list_detection_etl_workflow {str(sys.argv)}")
 
 
-# def host_list_02_workflow_manager_wrapper():
-#     queue_of_batch_names_loaded_into_sqlite = multiprocessing.Queue()
-#     queue_process = \
-#         multiprocessing.Process(target=host_list_02_workflow_manager.main,
-#                                 args=(queue_of_batch_names_loaded_into_sqlite,),
-#                                 name='host_list_02_workflow_manager')
-#     return queue_process,queue_of_batch_names_loaded_into_sqlite
-
-
 def spawn_knowledgebase_02_workflow_manager_wrapper():
     try:
         etld_lib_config.kb_last_modified_after = ""
@@ -98,40 +88,6 @@ def spawn_knowledgebase_02_workflow_manager_wrapper():
         raise Exception("Raise Exception from spawn_knowledgebase_02_workflow_manager_wrapper")
 
 
-# def get_knowledgebase_controller(kb_last_modified_after=None):
-#     if kb_last_modified_after is not None:
-#         etld_lib_config.kb_last_modified_after = kb_last_modified_after
-#     else:
-#         etld_lib_config.kb_last_modified_after = ""
-#
-#     def get_knowledgebase_data():
-#         try:
-#             knowledgebase_02_workflow_manager_wrapper()
-#         except Exception as e2:
-#             etld_lib_functions.logger.warning(f"Error get_knowledgebase_data")
-#             etld_lib_functions.logger.warning(f"Exception: {e2}")
-#             raise Exception("Raise Exception from host_list_detection_02_workflow_manager")
-#
-#     retry_attempts = 12
-#     retry_attempt = 0
-#     retry_sleep_time = 300
-#     while retry_attempt < retry_attempts:
-#         retry_attempt += 1
-#         try:
-#             with open(etld_lib_config.kb_lock_file, 'wb+') as lock_knowledgebase_fcntl:
-#                 fcntl.flock(lock_knowledgebase_fcntl, fcntl.LOCK_EX | fcntl.LOCK_NB)
-#                 get_knowledgebase_data()
-#                 break # Success
-#         except Exception as e:
-#             etld_lib_functions.logger.warning(f"KnowledgeBase Exception.  {__file__} ")
-#             etld_lib_functions.logger.warning(f"Retrying in {retry_sleep_time} seconds")
-#             time.sleep(retry_sleep_time)
-#     else:
-#         etld_lib_functions.logger.error(f"Retried {retry_attempt} times with no success.")
-#         etld_lib_functions.logger.error(f"Check to see if KnowledgeBase Program is already running.  {__file__} ")
-#         exit(1)
-
-
 def get_host_list_data():
 
     try:
@@ -232,5 +188,6 @@ def main():
 if __name__ == "__main__":
     etld_lib_functions.main(my_logger_prog_name='host_list_detection_02_workflow_manager')
     etld_lib_config.main()
-    etld_lib_credentials.main()
+    #etld_lib_credentials.main()
+    etld_lib_authentication_objects.main()
     main()
