@@ -8,7 +8,8 @@ import multiprocessing
 from pathlib import Path
 from qualys_etl.etld_lib import etld_lib_config
 from qualys_etl.etld_lib import etld_lib_functions
-from qualys_etl.etld_lib import etld_lib_credentials
+#from qualys_etl.etld_lib import etld_lib_credentials
+from qualys_etl.etld_lib import etld_lib_authentication_objects
 from qualys_etl.etld_lib import etld_lib_datetime
 from qualys_etl.etld_host_list_detection import host_list_detection_04_extract
 from qualys_etl.etld_host_list_detection import host_list_detection_05_transform_load_xml_to_sqlite
@@ -248,10 +249,11 @@ def test_child_processes_for_concurrency_max(
         queue_of_file_paths_to_load_to_sqlite=None
         ):
 
-    etld_lib_functions.logger.info(
-        f"test_child_processes_for_concurrency_max: {multiprocessing.active_children()}")
     active_children = get_count_of_active_child_processes('batch_')
     concurrency = int(etld_lib_config.host_list_detection_concurrency_limit)
+    etld_lib_functions.logger.info(f"test_child_processes_for_concurrency_max: "
+                                   f"active={active_children}, max={concurrency}, all_children="
+                                   f"{multiprocessing.active_children()}")
 
     while active_children >= concurrency:
         etld_lib_functions.logger.debug(f"active_children: {active_children} "
@@ -476,7 +478,8 @@ def extract_host_list_detection_via_multiprocessing_manager():
         xml_file_utc_run_datetime = etld_lib_datetime.get_utc_datetime_qualys_format()
 
         xml_file_paths_multiprocessing_queue = manager.Queue()
-        cred_dict = etld_lib_credentials.get_cred(cred_dict={})
+        #cred_dict = etld_lib_credentials.get_cred(cred_dict={})
+        cred_dict = etld_lib_authentication_objects.qualys_authentication_obj.get_credentials_dict()
 
         spawn_processes_to_extract_host_list_detection(
             host_list_detection_batch_queue=host_list_detection_batch_queue,
@@ -497,5 +500,6 @@ def main():
 if __name__ == "__main__":
     etld_lib_functions.main(my_logger_prog_name='host_list_detection_extract_03_controller')
     etld_lib_config.main()
-    etld_lib_credentials.main()
+    #etld_lib_credentials.main()
+    etld_lib_authentication_objects.main()
     main()
