@@ -1,7 +1,8 @@
 #!/usr/bin/env python3
 import os
 from pathlib import Path
-from qualys_etl.etld_lib import etld_lib_credentials
+#from qualys_etl.etld_lib import etld_lib_credentials
+from qualys_etl.etld_lib import etld_lib_authentication_objects
 from qualys_etl.etld_lib import etld_lib_config
 from qualys_etl.etld_lib import etld_lib_functions
 from qualys_etl.etld_lib import etld_lib_extract_transform_load
@@ -125,19 +126,22 @@ def test_one_batch():
             compression_method=etld_lib_config.host_list_detection_open_file_compression_method
         )
 
+    #cred_dict=etld_lib_credentials.get_cred(cred_dict={})
+    credentials_dict = etld_lib_authentication_objects.qualys_authentication_obj.get_credentials_dict()
     host_list_detection_extract(
         xml_file=file_info_dict['next_file_path'],
         batch_of_host_ids="",
         batch_number_str=file_info_dict['next_batch_number_str'],
         qualys_headers_multiprocessing_dict=None,
-        cred_dict=etld_lib_credentials.get_cred(cred_dict={})
+        cred_dict=credentials_dict
     )
 
 
 if __name__ == "__main__":
     etld_lib_functions.main(my_logger_prog_name='host_list_detection_04_extract')
     etld_lib_config.main()
-    etld_lib_credentials.main()
+    #etld_lib_credentials.main()
+    etld_lib_authentication_objects.main()
     main()
 
 
