@@ -9,7 +9,8 @@ import gzip
 
 from qualys_etl.etld_lib import etld_lib_config
 from qualys_etl.etld_lib import etld_lib_functions
-from qualys_etl.etld_lib import etld_lib_credentials
+#from qualys_etl.etld_lib import etld_lib_credentials
+from qualys_etl.etld_lib import etld_lib_authentication_objects
 from qualys_etl.etld_lib import etld_lib_sqlite_tables
 from qualys_etl.etld_lib import etld_lib_extract_transform_load
 from qualys_etl.etld_lib import etld_lib_datetime
@@ -835,5 +836,6 @@ def main(multiprocessing_flag=False, queue_of_file_paths: Queue = Queue()):
 if __name__ == "__main__":
     etld_lib_functions.main(my_logger_prog_name='host_list_detection_05_transform_load_xml_to_sqlite')
     etld_lib_config.main()
-    etld_lib_credentials.main()
+    #etld_lib_credentials.main()
+    etld_lib_authentication_objects.main()
     main(multiprocessing_flag=False, queue_of_file_paths=Queue())
