@@ -1,7 +1,8 @@
 #!/usr/bin/env python3
-from qualys_etl.etld_lib import etld_lib_config as etld_lib_config
-from qualys_etl.etld_lib import etld_lib_credentials as etld_lib_credentials
-from qualys_etl.etld_lib import etld_lib_functions as etld_lib_functions
+from qualys_etl.etld_lib import etld_lib_config
+#from qualys_etl.etld_lib import etld_lib_credentials
+from qualys_etl.etld_lib import etld_lib_authentication_objects
+from qualys_etl.etld_lib import etld_lib_functions
 from qualys_etl.etld_lib import etld_lib_csv_distribution
 
 
@@ -44,5 +45,6 @@ def main(test_extract=False):
 if __name__ == "__main__":
     etld_lib_functions.main(my_logger_prog_name='host_list_detection_06_distribution')
     etld_lib_config.main()
-    etld_lib_credentials.main()
+    #etld_lib_credentials.main()
+    etld_lib_authentication_objects.main()
     main(test_extract=True)
