@@ -4,7 +4,8 @@ import timeit
 from pathlib import Path
 from qualys_etl.etld_lib import etld_lib_functions
 from qualys_etl.etld_lib import etld_lib_config
-from qualys_etl.etld_lib import etld_lib_credentials
+#from qualys_etl.etld_lib import etld_lib_credentials
+from qualys_etl.etld_lib import etld_lib_authentication_objects
 
 from qualys_etl.etld_knowledgebase import knowledgebase_03_extract_controller
 from qualys_etl.etld_knowledgebase import knowledgebase_04_extract
@@ -44,9 +45,6 @@ def begin_knowledgebase_02_workflow_manager():
     start_time = timeit.default_timer()
     etld_lib_functions.logger.info(f"__start__ knowledgebase_etl_workflow {str(sys.argv)}")
     etld_lib_functions.logger.info(f"data directory: {etld_lib_config.qetl_user_data_dir}")
-    etld_lib_functions.logger.info(f"config file:    {etld_lib_config.qetl_user_config_settings_yaml_file}")
-    etld_lib_functions.logger.info(f"cred yaml file: {etld_lib_credentials.cred_file}")
-    etld_lib_functions.logger.info(f"cookie file:    {etld_lib_credentials.cookie_file}")
 
 
 def end_knowledgebase_02_workflow_manager():
@@ -78,5 +76,6 @@ def main():
 if __name__ == "__main__":
     etld_lib_functions.main(my_logger_prog_name="knowledgebase_02_workflow_manager")
     etld_lib_config.main()
-    etld_lib_credentials.main()
+    #etld_lib_credentials.main()
+    etld_lib_authentication_objects.main()
     main()
