@@ -1,5 +1,6 @@
 from pathlib import Path
 import os
+import csv
 import oschmod
 import gzip
 import re
@@ -16,6 +17,8 @@ global qetl_code_dir                  # Parent Directory of qualys_etl
 global qetl_code_dir_child            # qualys_etl directory
 global qetl_user_root_dir             # opt/qetl/users/{$USER NAME}
 global qetl_all_users_dir             # opt/qetl/users
+# TEMPLATES
+global qetl_code_dir_etld_cred_yaml_template_path  # Template for initializing .etld_cred.yaml file.
 # USER INIT
 global qetl_create_user_dirs_ok_flag  # False.  Set to true by qetl_manage_user
 global qualys_etl_user_home_env_var
@@ -24,6 +27,7 @@ global qetl_user_data_dir
 global qetl_user_log_dir
 global qetl_user_config_dir
 global qetl_user_cred_dir
+global qetl_user_cred_file
 global qetl_user_bin_dir
 global qetl_user_default_config
 global qetl_user_config_settings_yaml_file
@@ -237,8 +241,18 @@ global was_http_conn_timeout
 global was_open_file_compression_method
 global was_test_system_flag
 global was_test_number_of_files_to_extract
+global was_catalog_start_greater_than_last_id
 
-# initialize some globals
+# CSV Distribution CSV Writer Options
+global csv_distribution_python_csv_quoting
+global csv_distribution_python_csv_dialect_delimiter
+global csv_distribution_python_csv_dialect_doublequote
+global csv_distribution_python_csv_dialect_escapechar
+global csv_distribution_python_csv_dialect_lineterminator
+global csv_distribution_python_csv_dialect_quotechar
+global csv_distribution_python_csv_dialect_skipinitialspace
+global csv_distribution_python_csv_dialect_strict
+global csv_distribution_mysql_load_example
 
 qetl_create_user_dirs_ok_flag = False      # Automatically create unknown user directories default - False
 qetl_manage_user_selected_datetime = None  # Initialize qetl_manage_user datetime to None
@@ -435,12 +449,136 @@ def remove_old_files(dir_path=None,
         exit(1)
 
 
-def get_attribute_from_config_settings(key, default_value):
+def get_attribute_from_config_settings(key, default_value, fix_escape=False):
+    new_value = ""
     if key in etld_lib_config_settings_yaml_dict.keys():
-        return etld_lib_config_settings_yaml_dict.get(key)
+        new_value = etld_lib_config_settings_yaml_dict.get(key)
     else:
-        return default_value
+        new_value = default_value
+    if fix_escape and isinstance(new_value, str):
+        new_value = new_value.replace('\\n', '\n')
+        new_value = new_value.replace('\\t', '\t')
+        new_value = new_value.replace('\\\\', '\\')
 
+    return new_value
+
+
+def setup_csv_distribution_vars():
+    global csv_distribution_python_csv_quoting
+    global csv_distribution_python_csv_dialect_delimiter
+    global csv_distribution_python_csv_dialect_doublequote
+    global csv_distribution_python_csv_dialect_escapechar
+    global csv_distribution_python_csv_dialect_lineterminator
+    global csv_distribution_python_csv_dialect_quotechar
+    global csv_distribution_python_csv_dialect_skipinitialspace
+    global csv_distribution_python_csv_dialect_strict
+    global csv_distribution_mysql_load_example
+
+    # DEFAULTS SET HERE
+    # See https://docs.python.org/3/library/csv.html#csv-fmt-params
+    csv_distribution_python_csv_quoting = 'csv.QUOTE_NONE'
+    csv_distribution_python_csv_dialect_delimiter = '\t'
+    csv_distribution_python_csv_dialect_doublequote = False
+    csv_distribution_python_csv_dialect_escapechar = '\\'
+    csv_distribution_python_csv_dialect_lineterminator = '\n'
+    csv_distribution_python_csv_dialect_quotechar = None
+    csv_distribution_python_csv_dialect_skipinitialspace = False
+    csv_distribution_python_csv_dialect_strict = False
+    csv_distribution_mysql_load_example = '''mysql $PORT_OPT -v -e "LOAD DATA LOCAL INFILE '/dev/stdin' INTO TABLE ${TABLE_NAME} CHARACTER SET UTF8 FIELDS TERMINATED BY '\\t' ESCAPED BY '\\\\' LINES TERMINATED BY '\\n';"'''
+
+def get_python_csv_quoting_option_dict():
+    csv_quoting_dict = {
+        'csv.QUOTE_ALL': csv.QUOTE_ALL,
+        'csv.QUOTE_MINIMAL': csv.QUOTE_MINIMAL,
+        'csv.QUOTE_NONNUMERIC': csv.QUOTE_NONNUMERIC,
+        'csv.QUOTE_NONE': csv.QUOTE_NONE
+                        }
+    return csv_quoting_dict
+
+
+def get_python_csv_quoting_option_key(csv_value=None):
+    csv_key = ""
+    csv_quote_dict = get_python_csv_quoting_option_dict()
+    for key, value in csv_quote_dict.items():
+        if csv_value == value:
+            csv_key = key
+    return csv_key
+
+
+def get_csv_distribution_config():
+    global csv_distribution_python_csv_quoting
+    global csv_distribution_python_csv_dialect_delimiter
+    global csv_distribution_python_csv_dialect_doublequote
+    global csv_distribution_python_csv_dialect_escapechar
+    global csv_distribution_python_csv_dialect_lineterminator
+    global csv_distribution_python_csv_dialect_quotechar
+    global csv_distribution_python_csv_dialect_skipinitialspace
+    global csv_distribution_python_csv_dialect_strict
+
+    csv_quoting_dict = get_python_csv_quoting_option_dict()
+
+    csv_distribution_python_csv_quoting = \
+    get_attribute_from_config_settings('csv_distribution_python_csv_quoting',
+                                       csv_distribution_python_csv_quoting, True)
+    if csv_distribution_python_csv_quoting in csv_quoting_dict:
+        csv_quoting = csv_quoting_dict[csv_distribution_python_csv_quoting]
+        etld_lib_functions.logger.info(f"csv_distribution_python_csv_quoting: {csv_distribution_python_csv_quoting}"
+                                       f" is being reset to literal: {csv_quoting}")
+        csv_distribution_python_csv_quoting = csv_quoting
+    else:
+        etld_lib_functions.logger.error(f"invalid etld_config_settings.yaml seeting csv_distribution_python_csv_quoting: {csv_distribution_python_csv_quoting}")
+        etld_lib_functions.logger.error(f"error reported, setting to csv_distribution_python_csv_quoting to default csv.QUOTE_MINIMAL")
+        etld_lib_functions.logger.error(f"job will continue, please fix etld_config_settings.yaml.")
+        etld_lib_functions.logger.error(f"valid values for csv_distribution_python_csv_quoting are: 'csv.QUOTE_ALL' or 'csv.QUOTE_MINIMAL' or 'csv.QUOTE_NONNUMERIC' or 'csv.QUOTE_NONE'")
+        etld_lib_functions.logger.error(f"see python csv constants: https://docs.python.org/3/library/csv.html#csv.QUOTE_ALL")
+        csv_distribution_python_csv_quoting = csv.QUOTE_MINIMAL
+
+    csv_distribution_python_csv_dialect_delimiter = \
+    get_attribute_from_config_settings('csv_distribution_python_csv_dialect_delimiter',
+                                       csv_distribution_python_csv_dialect_delimiter, True)
+    csv_distribution_python_csv_dialect_doublequote = \
+    get_attribute_from_config_settings('csv_distribution_python_csv_dialect_doublequote',
+                                       csv_distribution_python_csv_dialect_doublequote, True)
+    csv_distribution_python_csv_dialect_escapechar = \
+    get_attribute_from_config_settings('csv_distribution_python_csv_dialect_escapechar',
+                                       csv_distribution_python_csv_dialect_escapechar, True)
+    csv_distribution_python_csv_dialect_lineterminator = \
+    get_attribute_from_config_settings('csv_distribution_python_csv_dialect_lineterminator',
+                                       csv_distribution_python_csv_dialect_lineterminator, True)
+    csv_distribution_python_csv_dialect_quotechar = \
+    get_attribute_from_config_settings('csv_distribution_python_csv_dialect_quotechar',
+                                       csv_distribution_python_csv_dialect_quotechar, True)
+    if csv_distribution_python_csv_dialect_quotechar == 'None':
+        csv_distribution_python_csv_dialect_quotechar = None
+
+    csv_distribution_python_csv_dialect_skipinitialspace = \
+    get_attribute_from_config_settings('csv_distribution_python_csv_dialect_skipinitialspace',
+                                       csv_distribution_python_csv_dialect_skipinitialspace, True)
+    csv_distribution_python_csv_dialect_strict = \
+    get_attribute_from_config_settings('csv_distribution_python_csv_dialect_strict',
+                                       csv_distribution_python_csv_dialect_strict, True)
+
+def get_csv_distribution_var_dict() -> dict:
+    global csv_distribution_python_csv_quoting
+    global csv_distribution_python_csv_dialect_delimiter
+    global csv_distribution_python_csv_dialect_doublequote
+    global csv_distribution_python_csv_dialect_escapechar
+    global csv_distribution_python_csv_dialect_lineterminator
+    global csv_distribution_python_csv_dialect_quotechar
+    global csv_distribution_python_csv_dialect_skipinitialspace
+    global csv_distribution_python_csv_dialect_strict
+
+    csv_distribution_writer_options = {
+        'quoting': csv_distribution_python_csv_quoting,
+        'delimiter': csv_distribution_python_csv_dialect_delimiter,
+        'doublequote': csv_distribution_python_csv_dialect_doublequote,
+        'escapechar': csv_distribution_python_csv_dialect_escapechar,
+        'lineterminator': csv_distribution_python_csv_dialect_lineterminator,
+        'quotechar': csv_distribution_python_csv_dialect_quotechar,
+        'skipinitialspace': csv_distribution_python_csv_dialect_skipinitialspace,
+        'strict': csv_distribution_python_csv_dialect_strict
+    }
+    return csv_distribution_writer_options
 
 def get_open_file_compression_method_from_config_settings(key):
     compression_method = gzip.open
@@ -471,6 +609,7 @@ def set_path_qetl_user_home_dir():
     global qetl_user_log_dir
     global qetl_user_config_dir
     global qetl_user_cred_dir
+    global qetl_user_cred_file
     global qetl_user_bin_dir
 
     if os.environ.keys().__contains__("qualys_etl_user_home") is not True:
@@ -520,8 +659,10 @@ def set_path_qetl_user_home_dir():
     qetl_user_log_dir = Path(qetl_user_home_dir, "log")
     qetl_user_config_dir = Path(qetl_user_home_dir, "config")
     qetl_user_cred_dir = Path(qetl_user_home_dir, "cred")
+    qetl_user_cred_file = Path(qetl_user_cred_dir, ".etld_cred.yaml")
     qetl_user_bin_dir = Path(qetl_user_home_dir, "bin")
     validate_char_qetl_user_home_dir(qetl_user_home_dir)
+    setup_csv_distribution_vars()
     setup_kb_vars()
     setup_host_list_vars()
     setup_host_list_detection_vars()
@@ -644,12 +785,14 @@ def setup_user_home_directories():
     global qetl_user_log_dir             # logs
     global qetl_user_config_dir          # configuration
     global qetl_user_cred_dir            # credentials
+    global qetl_user_cred_file           # credentials
     global qetl_user_bin_dir             # TODO determine what to do with qetl_user_bin_dir
 
     global qetl_user_config_settings_yaml_file
     global qetl_user_config_settings_yaml
 
     global qetl_code_dir                 # Parent Directory of qualys_etl code dir.
+    global qetl_code_dir_etld_cred_yaml_template_path
     global qetl_user_default_config      # Initial configuration populated into qetl_user_config_dir
 
     set_path_qetl_user_home_dir()
@@ -676,6 +819,7 @@ def load_etld_lib_config_settings_yaml():
     global qetl_user_log_dir
     global qetl_user_config_dir
     global qetl_user_cred_dir
+    global qetl_user_cred_file
     global qetl_user_bin_dir
     global qetl_user_default_config
     global etld_lib_config_settings_yaml_dict
@@ -1343,6 +1487,7 @@ def get_was_user_config():
     global was_open_file_compression_method
     global was_test_system_flag
     global was_test_number_of_files_to_extract
+    global was_catalog_start_greater_than_last_id
 
     def set_was_webapp_last_scan_date():
         global was_webapp_last_scan_date
@@ -1386,6 +1531,8 @@ def get_was_user_config():
     was_test_system_flag = get_attribute_from_config_settings('was_test_system_flag', False)
     was_test_number_of_files_to_extract = \
         get_attribute_from_config_settings('was_test_number_of_files_to_extract', 3)
+    was_catalog_start_greater_than_last_id = \
+        get_attribute_from_config_settings('was_catalog_start_greater_than_last_id', 0)
     set_was_webapp_last_scan_date()
 
     etld_lib_functions.logger.info(f"was_export_dir - {was_export_dir}")
@@ -1456,6 +1603,12 @@ def get_qetl_code_dir():
     qetl_code_dir_child = etld_lib_functions.qetl_code_dir_child
 
 
+def set_qetl_code_dir_etld_cred_yaml_template_path():
+    global qetl_code_dir_etld_cred_yaml_template_path
+    qetl_code_dir_etld_cred_yaml_template_path = \
+        Path(etld_lib_functions.qetl_code_dir, "qualys_etl", "etld_templates", ".etld_cred.yaml")
+
+
 def setup_requests_module_tls_verify_status():
     global requests_module_tls_verify_status
     if 'requests_module_tls_verify_status' in etld_lib_config_settings_yaml_dict:
@@ -1596,13 +1749,19 @@ def host_list_detection_qids_csv_column_types():  # Return list of csv columns
 
 
 def asset_inventory_csv_columns():  # Return list of csv columns updated 0.6.111
+    # Added 2022-12-16 - "sensor_lastPcScanDateAgent", "sensor_lastPcScanDateScanner"
+    # Added 2022-12-16 - "sensor_lastVmScanDateAgent", "sensor_lastVmScanDateScanner"
 
     csv_columns = [
         'assetId', 'assetUUID', 'hostId', 'lastModifiedDate', 'agentId', 'createdDate', 'sensorLastUpdatedDate',
-        'sensor_lastVMScanDate', 'sensor_lastComplianceScanDate', 'sensor_lastFullScanDate', 'inventory_createdDate',
+        'sensor_lastVMScanDate', 'sensor_lastComplianceScanDate', 'sensor_lastFullScanDate',
+        'sensor_lastPcScanDateAgent', 'sensor_lastPcScanDateScanner',
+        'sensor_lastVmScanDateAgent', 'sensor_lastVmScanDateScanner',
+        'inventory_createdDate',
         'inventory_lastUpdatedDate', 'agent_lastActivityDate', 'agent_lastCheckedInDate', 'agent_lastInventoryDate',
         'assetType', 'address', 'dnsName', 'assetName', 'netbiosName', 'timeZone', 'biosDescription', 'lastBoot',
-        'totalMemory', 'cpuCount', 'lastLoggedOnUser', 'domainRole', 'hwUUID', 'biosSerialNumber', 'biosAssetTag', 'isContainerHost',
+        'totalMemory', 'cpuCount', 'lastLoggedOnUser', 'domainRole', 'hwUUID', 'biosSerialNumber', 'biosAssetTag',
+        'isContainerHost',
         'operatingSystem', 'hardware', 'userAccountListData', 'openPortListData', 'volumeListData',
         'networkInterfaceListData', 'softwareListData', 'provider', 'cloudProvider', 'agent', 'sensor', 'container',
         'inventory', 'activity', 'tagList', 'serviceList', 'lastLocation', 'criticality',
@@ -1844,10 +2003,14 @@ def check_ram_space():
 
 def main():
     get_qetl_code_dir()
+    set_qetl_code_dir_etld_cred_yaml_template_path()
     setup_user_home_directories()
     load_etld_lib_config_settings_yaml()
     setup_requests_module_tls_verify_status()
 
+    setup_csv_distribution_vars()
+    get_csv_distribution_config()
+
     setup_kb_vars()
     get_kb_user_config()
 
