@@ -13,6 +13,7 @@ from qualys_etl.etld_lib import etld_lib_functions
 from qualys_etl.etld_lib import etld_lib_config
 from qualys_etl.etld_lib import etld_lib_datetime
 import qualys_etl
+from qualys_etl.etld_lib import etld_lib_authentication_objects
 
 global cred_dir
 global cookie_file
@@ -24,6 +25,7 @@ global login_gateway_failed
 global http_return_code
 global platform_url
 global injected_stdin_cred
+global qualys_authentication_obj
 
 
 # https://www.qualys.com/platform-identification/
@@ -204,7 +206,7 @@ def get_cred(cred_dict={}):
     if not Path.is_file(cred_file):
         cred_example_file_path = \
             Path(etld_lib_functions.qetl_code_dir, "qualys_etl", "etld_templates", ".etld_cred.yaml")
-        destination_file_path = Path(cred_dir, ".etld_cred.yaml")
+        destination_file_path = Path(cred_file)
         shutil.copy(str(cred_example_file_path), str(destination_file_path), follow_symlinks=True)
         cred_example_file = open(str(cred_example_file_path), "r", encoding='utf-8')
         cred_example = cred_example_file.read()
@@ -225,11 +227,8 @@ def get_cred(cred_dict={}):
         cred['bearer'] = cred_dict['bearer']
     else:
         cred['bearer'] = ""
-    if 'timer_obj' in cred_dict.keys():
-        # setup for bearer token timer get_bearer_stored_in_env
-        cred['timer_obj'] = cred_dict['timer_obj']
-    else:
-        cred['timer_obj'] = None
+
+    cred['timer_obj'] = None
 
     return {'api_fqdn_server': cred['api_fqdn_server'],
             'gateway_fqdn_server': cred['gateway_fqdn_server'],
@@ -247,19 +246,19 @@ def get_bearer_stored_in_env(update_bearer=True, cred=None):
     max_age_of_bearer_token = 300
 
     timer_obj_update_bearer = False
-    if 'timer_obj' in cred.keys() and cred['timer_obj'] is not None:
-        timer_obj: etld_lib_functions.TimerObj = cred['timer_obj']
-        time_elapsed = timer_obj.get_time_elapsed()
-        time_elapsed_flag = timer_obj.if_time_elapsed_past_max_time(max_time=max_age_of_bearer_token)
-        if time_elapsed_flag:
-            timer_obj_update_bearer = True
-            timer_obj.reset_timer()
-            etld_lib_functions.logger.info(f"time elapsed: {time_elapsed:,.0f} seconds")
-        else:
-            timer_obj_update_bearer = False
-        cred['timer_obj'] = timer_obj
-    else:
-        cred['timer_obj'] = etld_lib_functions.TimerObj()
+    # if 'timer_obj' in cred.keys() and cred['timer_obj'] is not None:
+    #     timer_obj: etld_lib_functions.TimerObj = cred['timer_obj']
+    #     time_elapsed = timer_obj.get_time_elapsed()
+    #     time_elapsed_flag = timer_obj.if_time_elapsed_past_max_time(max_time=max_age_of_bearer_token)
+    #     if time_elapsed_flag:
+    #         timer_obj_update_bearer = True
+    #         timer_obj.reset_timer()
+    #         etld_lib_functions.logger.info(f"time elapsed: {time_elapsed:,.0f} seconds")
+    #     else:
+    #         timer_obj_update_bearer = False
+    #     cred['timer_obj'] = timer_obj
+    # else:
+    #     cred['timer_obj'] = etld_lib_functions.TimerObj()
 
     # TODO move away from file to timerobj for bearer token update.
 
@@ -397,7 +396,6 @@ def test_qualys_login_logout_basic_auth() -> dict:
                 etld_lib_functions.logger.warning(f"Exception: {e}")
                 pass
 
-
     def qualys_login_test() -> dict:
         login_status = {}
         login_status['login_failed'] = True
@@ -461,15 +459,20 @@ def main():
     global bearer_file
     global cred_file
     global use_cookie
+    global qualys_authentication_obj
     cred_dir = Path(etld_lib_config.qetl_user_cred_dir)  # Credentials Directory
-    cookie_file = Path(cred_dir, ".etld_cookie")  # Cookie File
-    bearer_file = Path(cred_dir, ".etld_bearer")  # Bearer File
-    cred_file = Path(cred_dir, ".etld_cred.yaml")  # YAML Format Qualys Credentials
-    use_cookie = False  # Set to true by qualys_login()
-
+    cookie_file = Path(cred_dir, ".etld_cookie")   # Never Used
+    bearer_file = Path(cred_dir, ".etld_bearer")   # Dummy data, used to determine age of bearer, old replace by obj
+    cred_file = Path(etld_lib_config.qetl_user_cred_file)  # YAML Format Qualys Credentials
+    use_cookie = False
+    # qualys_authentication_obj = etld_lib_authentication_objects.get_qualys_authentication_obj()
+    # qualys_authentication_obj.get_current_bearer_token()
+    # qualys_authentication_obj.get_authorization()
+    # print(qualys_authentication_obj.__dir__())
+    # print(qualys_authentication_obj.__dict__)
 
 if __name__ == '__main__':
     etld_lib_functions.main()
     etld_lib_config.main()
     main()
-    test_qualys_login_logout_basic_auth()
+#    test_qualys_login_logout_basic_auth()
