@@ -24,10 +24,22 @@ class CsvDistribution():
             self.create_directory(target_csv_data_directory)
 
     def set_csv_writer_with_file_handle(self, file_handle):
+        csv_key = etld_lib_config.get_python_csv_quoting_option_key(
+            csv_value=etld_lib_config.csv_distribution_python_csv_quoting
+        )
+        etld_lib_functions.logger.info(f"python_csv_options: {csv_key} {etld_lib_config.get_csv_distribution_var_dict()}")
+        #etld_lib_functions.logger.info(
+        #    f"tested_mysql_load_example: {etld_lib_config.csv_distribution_mysql_load_example} "
+        #    f"- note bash requires additional \\")
         csv_writer = csv.writer(file_handle,
-                                delimiter=',', lineterminator='\n',
-                                quoting=csv.QUOTE_NONE,
-                                escapechar='\\'
+                                quoting=etld_lib_config.csv_distribution_python_csv_quoting,
+                                delimiter=etld_lib_config.csv_distribution_python_csv_dialect_delimiter,
+                                doublequote=etld_lib_config.csv_distribution_python_csv_dialect_doublequote,
+                                escapechar=etld_lib_config.csv_distribution_python_csv_dialect_escapechar,
+                                lineterminator=etld_lib_config.csv_distribution_python_csv_dialect_lineterminator,
+                                quotechar=etld_lib_config.csv_distribution_python_csv_dialect_quotechar,
+                                skipinitialspace=etld_lib_config.csv_distribution_python_csv_dialect_skipinitialspace,
+                                strict=etld_lib_config.csv_distribution_python_csv_dialect_strict
                                 )
         self.csv_writer = csv_writer
 
@@ -45,10 +57,26 @@ class CsvDistribution():
 
     @staticmethod
     def get_csv_writer(csv_file, csv_open_method=open):
+        #delimiter=',',
+        #lineterminator='\n',
+        #quoting=csv.QUOTE_NONE,
+        #escapechar='\\'
+        csv_key = etld_lib_config.get_python_csv_quoting_option_key(
+            csv_value=etld_lib_config.csv_distribution_python_csv_quoting
+        )
+        etld_lib_functions.logger.info(f"python_csv_options: {csv_key} {etld_lib_config.get_csv_distribution_var_dict()}")
+        #etld_lib_functions.logger.info(
+        #    f"tested_mysql_load_example: {etld_lib_config.csv_distribution_mysql_load_example} "
+        #    f"- note bash requires additional \\")
         csv_writer = csv.writer(csv_open_method(csv_file, 'wt', newline=''),
-                                delimiter=',', lineterminator='\n',
-                                quoting=csv.QUOTE_NONE,
-                                escapechar='\\'
+                                quoting=etld_lib_config.csv_distribution_python_csv_quoting,
+                                delimiter=etld_lib_config.csv_distribution_python_csv_dialect_delimiter,
+                                doublequote=etld_lib_config.csv_distribution_python_csv_dialect_doublequote,
+                                escapechar=etld_lib_config.csv_distribution_python_csv_dialect_escapechar,
+                                lineterminator=etld_lib_config.csv_distribution_python_csv_dialect_lineterminator,
+                                quotechar=etld_lib_config.csv_distribution_python_csv_dialect_quotechar,
+                                skipinitialspace=etld_lib_config.csv_distribution_python_csv_dialect_skipinitialspace,
+                                strict=etld_lib_config.csv_distribution_python_csv_dialect_strict
                                 )
         return csv_writer
 
@@ -304,6 +332,7 @@ def distribute_csv_data_for_one_workflow(distribution_csv_flag=False,
     if exclude_table_names == None:
         exclude_table_names = []
 
+
     counter_obj_dict = {}
     if distribution_csv_flag:
         try:
