@@ -12,6 +12,7 @@ from qualys_etl.etld_lib import etld_lib_functions
 from qualys_etl.etld_lib import etld_lib_sqlite_tables
 from qualys_etl.etld_lib import etld_lib_test_system
 from qualys_etl.etld_lib import etld_lib_credentials
+from qualys_etl.etld_lib import etld_lib_authentication_objects
 global http_error_codes_v2_api
 
 
@@ -332,7 +333,9 @@ def extract_qualys(
                         etld_lib_functions.logger.warning(f"HTTP {r.status_code}: warning. message={message}")
                         etld_lib_functions.logger.warning(f"HTTP {r.status_code}: "
                                                           f"retrying cred gateway for:{url}")
-                        cred_dict = etld_lib_credentials.get_bearer_stored_in_env(update_bearer=True, cred=cred_dict)
+                        etld_lib_authentication_objects.qualys_authentication_obj.get_current_bearer_token(force_update_to_bearer_token=True)
+                        cred_dict = etld_lib_authentication_objects.qualys_authentication_obj.get_credentials_dict()
+                        #cred_dict = etld_lib_credentials.get_bearer_stored_in_env(update_bearer=True, cred=cred_dict)
                         raise Exception(f"HTTP Status is: {r.status_code}, message: {message}")
                     else:
                         message = get_http_error_code_message_v2_api(str(r.status_code))
