@@ -21,6 +21,7 @@ global my_logger_program_name_for_database_routine
 global logger_to_file
 global logging_level
 global qetl_code_dir        # Parent of qualys_etl directory
+global qetl_code_dir_etld_cred_yaml_template_path
 global qetl_code_dir_child  # qualys_etl directory
 global qetl_pip_installed_version  # qetl installed through pip
 import qualys_etl
@@ -28,58 +29,10 @@ import qualys_etl
 logging_is_on_flag = False
 
 
-# def get_dbm_type(file_name):
-#     dbm_type = dbm.whichdb(file_name)
-#     if dbm_type == '':
-#         dbm_type = 'unknown'
-#
-#     return dbm_type
-
-
-# def flatten_nest(nested_data):  # Flatten nested dictionary into string
-#     def nested_items():
-#         if isinstance(nested_data, list):
-#             for key, value in enumerate(nested_data):
-#                 if isinstance(value, dict) or isinstance(value, list):
-#                     for nested_key, nested_value in flatten_nest(value).items():
-#                         yield str(key) + "." + nested_key, nested_value
-#                 else:
-#                     yield str(key), value
-#         else:
-#             for key, value in nested_data.items():
-#                 if isinstance(value, dict) or isinstance(value, list):
-#                     for nested_key, nested_value in flatten_nest(value).items():
-#                         yield key + "." + nested_key, nested_value
-#                 else:
-#                     yield key, value
-#     return dict(nested_items())
-#
-#
-# def remove_low_high_values(chunk):  # Remove utf-8 values other than utf-8 decimal 10, 32-126
-#     encoding = chardet.detect(chunk)['encoding']
-#     chunk = chunk.decode(encoding, 'replace')
-#     new_chunk = ''
-#     for index in range(0, len(chunk)):
-#         try:
-#             size = ord(chunk[index])
-#             if (size == 10) or (size == 9) or (127 > size > 31):
-#                 new_chunk = new_chunk + chunk[index]
-#             else:
-#                 new_chunk = new_chunk + ""
-#         except Exception as e:
-#             new_chunk = new_chunk + ""
-#     chunk = new_chunk.encode('utf-8')
-#     return chunk
-#
-#
-# def truncate_csv_cell(max_length=32700, csv_cell="", truncated_field_list="", csv_column=""):
-#     if max_length == 0:
-#         pass
-#     elif len(csv_cell) > max_length:
-#         truncated_field_list = f"{truncated_field_list}{csv_column}:{len(csv_cell):,} truncated_at: {max_length:,}\n"
-#         csv_cell = csv_cell[:max_length]
-#
-#     return csv_cell, truncated_field_list
+def set_qetl_code_dir_etld_cred_yaml_template_path():
+    global qetl_code_dir_etld_cred_yaml_template_path
+    qetl_code_dir_etld_cred_yaml_template_path = \
+        Path(qetl_code_dir, "qualys_etl", "etld_templates", ".etld_cred.yaml")
 
 
 def check_python_version():
@@ -107,15 +60,6 @@ def get_file_mtime(path_to_file):
         return statinfo.st_mtime
 
 
-# def dbm_type_message(dbm_file):
-#     dbm_type = get_dbm_type(str(dbm_file))
-#     if dbm_type == "dbm.gnu":
-#         message = "dbm.gnu is best performing DBM, you are good to go!"
-#     else:
-#         message = f"{dbm_type} may result in errors.  Please consider moving to dbm.gnu which is optimal."
-#     return message
-
-
 def get_sqlite_version():
     global logger
     import sqlite3
@@ -161,16 +105,6 @@ def setup_logging_stdout(log_level=logging.INFO, my_logger_prog_name=None):
     logger.info(f"LOGGING SUCCESSFULLY SETUP FOR STREAMING")
 
 
-# def setup_logging_to_file(logfile_path, log_level=logging.INFO):
-#     logging.Formatter.converter = time.gmtime
-#     logging.basicConfig(format=f"%(asctime)s - %(levelname)s - %(message)s",
-#                         filename=logfile_path,
-#                         level=log_level)
-#     global logger
-#     logger = logging.getLogger(__name__)
-#     logger.info(f"LOGGING SUCCESSFULLY SETUP TO {str(logfile_path)}")
-
-
 def lineno():
     return inspect.currentframe().f_back.f_lineno
 
@@ -191,11 +125,6 @@ def check_modules():
         exit(1)
 
 
-# def set_logging_level(log_level=logging.INFO):
-#     global logging_level
-#     logging_level = log_level  # Set to logging.WARNING to only log Warnings and Errors.
-
-
 def set_qetl_code_dir(log=True): # Module Directories
     global qetl_code_dir         # Parent of qualys_etl directory
     global qetl_code_dir_child   # qualys_etl directory
@@ -238,26 +167,6 @@ def set_qetl_code_dir(log=True): # Module Directories
     logger.info(f"etld_host_list        - {qetl_code_dir_child_api_host_list}")
 
 
-# def log_dbm_info(file_name, msg=""):
-#     if exists(str(file_name)):
-#         dbm_type = get_dbm_type(str(file_name))
-#         logger.info(f"{msg}dbm etl_workflow_validation_type - {dbm_type} - {str(file_name)}")
-#         if dbm_type == "dbm.gnu" or dbm_type is None:
-#             pass
-#         else:
-#             logger.info(f"{msg}dbm etl_workflow_validation_type warning - {dbm_type} may lead to inconsistent results.")
-#             logger.info(f"{msg}dbm etl_workflow_validation_type warning - {dbm_type} move to linux gnu dbm.")
-
-
-# def log_dbm_count_of_keys_found(file_name):
-#     if exists(str(file_name)):
-#         dbm_type = get_dbm_type(str(file_name))
-#         if dbm_type == "dbm.gnu" or dbm_type is None:
-#             with dbm.gnu.open(str(file_name), 'rf') as sd:
-#                 count = len(sd)
-#                 logger.info(f"keys found: {count:,} in dbm.gnu shelve: {str(file_name)}")
-
-
 def get_formatted_file_info_dict(file_name):
     file_path = Path(file_name)
     if file_path.is_file():
@@ -299,42 +208,6 @@ def log_file_info(file_name, msg1='output file'):
                 f"change time: {file_info.get('file_change_time')}")
 
 
-# def file_is_locked(test_lock_file=None):
-#     # TODO determine if checking locking in each method is needed.
-#     # TODO note that all actions should be run through qetl_manage_user which locks the jobstream.
-#     try:
-#         if Path(test_lock_file).is_file():
-#             with open(test_lock_file, 'wb+') as tlf:        # If locked, exit.
-#                 # lock file is free
-#                 return False
-#         else:
-#             # lock file doesn't exist
-#             return False
-#     except Exception as e:
-#         return True
-
-class TimerObj:
-    def __init__(self):
-        self.start_time = timeit.default_timer()
-        self.current_time = self.start_time
-        self.time_elapsed = 0
-
-    def reset_timer(self):
-        self.start_time = timeit.default_timer()
-        self.current_time = self.start_time
-        self.time_elapsed = 0
-
-    def get_time_elapsed(self) -> float:
-        current_time = timeit.default_timer()
-        time_elapsed = (current_time - self.start_time)
-        return time_elapsed
-
-    def if_time_elapsed_past_max_time(self, max_time=300) -> bool:
-        time_elapsed = self.get_time_elapsed()
-        time_elapsed_flag = False
-        if time_elapsed > max_time:
-            time_elapsed_flag = True
-        return time_elapsed_flag
 
 
 class DisplayCounterToLog:
@@ -518,15 +391,6 @@ def if_ram_space_size_is_low_log_warning(logger_method=print):
                       f'Consider increasing RAM to support larger batch jobs and sql queries')
 
 
-# def proc_table(logger_method=print):
-#     for proc in psutil.process_iter(['pid', 'name']):
-#         if 'python' in proc.info['name']:
-#             p = psutil.Process(proc.pid)
-#             #p.open_files().count()
-#             logger_method(f'SYS STAT: PID COMMAND={proc.pid}, OPEN_FILES={p.open_files()}, CMD={p.cmdline()}')
-#             logger_method(f'PID STAT: PID CHILDREN={proc.pid}, CHILDREN={p.children(recursive=True)}')
-
-
 def get_disk_usage_pct(data_dir="/opt/qetl/users"):
     return psutil.disk_usage(data_dir).percent
 
@@ -595,11 +459,13 @@ def get_swap_usage_pct():
 
 def main(log_level=logging.INFO, my_logger_prog_name=None):
     global logging_level
+    global qetl_code_dir_etld_cred_yaml_template_path
     setup_logging_stdout(log_level, my_logger_prog_name)
     check_modules()
     check_python_version()
     get_sqlite_version()
     set_qetl_code_dir()
+    set_qetl_code_dir_etld_cred_yaml_template_path()
 
 
 if __name__ == '__main__':
