@@ -12,6 +12,7 @@ from contextlib import redirect_stdout, redirect_stderr
 
 from qualys_etl.etld_lib import etld_lib_config
 from qualys_etl.etld_lib import etld_lib_credentials
+from qualys_etl.etld_lib import etld_lib_authentication_objects
 from qualys_etl.etld_lib import etld_lib_functions
 from qualys_etl.etld_lib import etld_lib_log_validation
 
@@ -219,6 +220,8 @@ def etl_main():
                         etld_lib_functions.main(my_logger_prog_name=target_module_to_run.__name__)
                         etld_lib_config.main()
                         etld_lib_credentials.main()
+                        etl_workflow = target_method_in_module_to_run
+                        etld_lib_authentication_objects.main(http_user_agent_etl_workflow_message=etl_workflow,test_basic_authorization=True)
                         spawn_etl_in_background()
                         log_fo.flush()
                         time.sleep(1)
