@@ -439,7 +439,7 @@ class SqliteObj:
         return field_data
 
     def prepare_database_row_asset_inventory(self, item_dict: dict, csv_columns: list, csv_column_types: list,
-                                            batch_name: str, batch_date: str, batch_number: str):
+                                             batch_name: str, batch_date: str, batch_number: str):
         row_in_sqlite_form = []
         for field_name in csv_columns:  # Iterate through expected columns (contract)
             if field_name in item_dict.keys():  # Iterate through columns found in dictionary
@@ -484,27 +484,27 @@ class SqliteObj:
 
         return field_data
 
-    def prepare_database_field(self, field_data, field_name_tmp, field_column_type) -> dict:
-        if field_column_type == 'INTEGER':
-            field_data = str(field_data).strip()
-            if str(field_data).isnumeric():
-                field_data = str(field_data)
-            else:
-                field_data = '0'
-        elif field_data is None:
-            field_data = ""
-        elif isinstance(field_data, str):
-            if 'date' in str(field_name_tmp).lower():
-                field_data = field_data.replace("T", " ").replace("Z", "")
-                field_data = re.sub("\\..*$", "", field_data)
-            elif 'dns' in str(field_name_tmp).lower():
-                field_data = field_data.replace('\n', '')
-        elif isinstance(field_data, int):
-            field_data = str(field_data)
-        elif not isinstance(field_data, str):
-            field_data = json.dumps(field_data)
-
-        return field_data
+    # def prepare_database_field(self, field_data, field_name_tmp, field_column_type) -> dict:
+    #     if field_column_type == 'INTEGER':
+    #         field_data = str(field_data).strip()
+    #         if str(field_data).isnumeric():
+    #             field_data = str(field_data)
+    #         else:
+    #             field_data = '0'
+    #     elif field_data is None:
+    #         field_data = ""
+    #     elif isinstance(field_data, str):
+    #         if 'date' in str(field_name_tmp).lower():
+    #             field_data = field_data.replace("T", " ").replace("Z", "")
+    #             field_data = re.sub("\\..*$", "", field_data)
+    #         elif 'dns' in str(field_name_tmp).lower():
+    #             field_data = field_data.replace('\n', '')
+    #     elif isinstance(field_data, int):
+    #         field_data = str(field_data)
+    #     elif not isinstance(field_data, str):
+    #         field_data = json.dumps(field_data)
+    #
+    #     return field_data
 
     # def prepare_database_row_integer_fields(self, item: dict, database_columns: list, database_column_types: dict) -> list:
     #     for field_name in database_columns:
@@ -523,19 +523,19 @@ class SqliteObj:
     #             row_in_sqlite_form.append("")  # Ensure blank is added to each required empty field
     #
 
-    def prepare_database_row(self, item: dict, database_columns: list, database_column_types: dict) -> list:
-        row_in_sqlite_form = []
-        for field_name in database_columns:
-            if field_name in item.keys():
-                field_column_type = ""
-                if field_name in database_column_types:
-                    field_column_type = database_column_types[field_name]
-                item[field_name] = \
-                    self.prepare_database_field(item[field_name], field_name, field_column_type)
-                row_in_sqlite_form.append(item[field_name])
-            else:
-                row_in_sqlite_form.append("")  # Ensure blank is added to each required empty field
-        return row_in_sqlite_form
+    # def prepare_database_row(self, item: dict, database_columns: list, database_column_types: dict) -> list:
+    #     row_in_sqlite_form = []
+    #     for field_name in database_columns:
+    #         if field_name in item.keys():
+    #             field_column_type = ""
+    #             if field_name in database_column_types:
+    #                 field_column_type = database_column_types[field_name]
+    #             item[field_name] = \
+    #                 self.prepare_database_field(item[field_name], field_name, field_column_type)
+    #             row_in_sqlite_form.append(item[field_name])
+    #         else:
+    #             row_in_sqlite_form.append("")  # Ensure blank is added to each required empty field
+    #     return row_in_sqlite_form
 
     # def prepare_integer_columns_for_database(self, table_name: str, row: list):
     #     if table_name in self.pragma_dict:
