@@ -7,6 +7,7 @@ import re
 import gzip
 from qualys_etl.etld_lib import etld_lib_config
 from qualys_etl.etld_lib import etld_lib_credentials
+from qualys_etl.etld_lib import etld_lib_authentication_objects
 from qualys_etl.etld_lib import etld_lib_functions
 from qualys_etl.etld_lib import etld_lib_extract_transform_load
 from qualys_etl.etld_lib import etld_lib_datetime
@@ -321,7 +322,7 @@ def test_was_count():
             batch_number_str='batch_000001',
             qualys_headers_dict={},
             file_info_dict=file_info_dict,
-            cred_dict=etld_lib_credentials.get_cred(),
+            cred_dict=etld_lib_authentication_objects.qualys_authentication_obj.get_credentials_dict(),
         )
     except Exception as e:
         etld_lib_functions.logger.error(f"Failed Test: Exception{e}")
@@ -401,6 +402,7 @@ if __name__ == "__main__":
     etld_lib_functions.main(my_logger_prog_name='etld_lib_test')
     etld_lib_config.main()
     etld_lib_credentials.main()
+    etld_lib_authentication_objects.main()
     arguments = sys.argv
     if len(arguments) > 1:
         test_function_to_run = arguments[1]
