@@ -3,7 +3,8 @@ import sys
 import timeit
 from qualys_etl.etld_lib import etld_lib_functions
 from qualys_etl.etld_lib import etld_lib_config
-from qualys_etl.etld_lib import etld_lib_credentials
+#from qualys_etl.etld_lib import etld_lib_credentials
+from qualys_etl.etld_lib import etld_lib_authentication_objects
 from qualys_etl.etld_test_system import test_system_03_controller
 
 
@@ -19,8 +20,6 @@ def test_system_03_extract_controller_wrapper(module_function=test_system_03_con
 
 def begin_message():
     etld_lib_functions.logger.info(f"data directory: {etld_lib_config.qetl_user_data_dir}")
-    etld_lib_functions.logger.info(f"config file:    {etld_lib_config.qetl_user_config_settings_yaml_file}")
-    etld_lib_functions.logger.info(f"cred yaml file: {etld_lib_credentials.cred_file}")
 
 
 def begin_test_system_02_workflow_manager():
@@ -56,5 +55,6 @@ def main():
 if __name__ == "__main__":
     etld_lib_functions.main(my_logger_prog_name='test_system_etl_workflow')
     etld_lib_config.main()
-    etld_lib_credentials.main()
+    #etld_lib_credentials.main()
+    etld_lib_authentication_objects.main()
     main()
\ No newline at end of file
