@@ -6,6 +6,7 @@ from pathlib import Path
 from qualys_etl.etld_lib import etld_lib_functions
 from qualys_etl.etld_lib import etld_lib_config
 from qualys_etl.etld_lib import etld_lib_credentials
+from qualys_etl.etld_lib import etld_lib_authentication_objects
 
 from qualys_etl.etld_was import was_03_extract_controller
 from qualys_etl.etld_was import was_05_transform_load_json_to_sqlite
@@ -45,9 +46,6 @@ def begin_was_02_workflow_manager():
     start_time = timeit.default_timer()
     etld_lib_functions.logger.info(f"__start__ was_etl_workflow {str(sys.argv)}")
     etld_lib_functions.logger.info(f"data directory: {etld_lib_config.qetl_user_data_dir}")
-    etld_lib_functions.logger.info(f"config file:    {etld_lib_config.qetl_user_config_settings_yaml_file}")
-    etld_lib_functions.logger.info(f"cred yaml file: {etld_lib_credentials.cred_file}")
-    etld_lib_functions.logger.info(f"bearer file:    {etld_lib_credentials.bearer_file}")
 
 
 def end_was_02_workflow_manager():
@@ -78,8 +76,8 @@ def main():
 
 
 if __name__ == "__main__":
-    #etld_lib_functions = etld_lib_functions_obj.StartLoggingToStdout(my_logger_prog_name='was_etl_workflow')
     etld_lib_functions.main(my_logger_prog_name='was_02_workflow_manager')
     etld_lib_config.main()
-    etld_lib_credentials.main()
+    #etld_lib_credentials.main()
+    etld_lib_authentication_objects.main()
     main()
