@@ -5,6 +5,7 @@ import multiprocessing
 from pathlib import Path
 from qualys_etl.etld_lib import etld_lib_config
 from qualys_etl.etld_lib import etld_lib_credentials
+from qualys_etl.etld_lib import etld_lib_authentication_objects
 from qualys_etl.etld_lib import etld_lib_functions
 from qualys_etl.etld_lib import etld_lib_datetime
 from qualys_etl.etld_lib import etld_lib_extract_transform_load
@@ -64,6 +65,10 @@ def get_was_count(_: dict):
     utc_datetime = _['utc_datetime']
     cred_dict = _['cred_dict']
     dir_search_glob = _['dir_search_glob']
+    # if 'last_id' in _.keys():
+    #     last_id = _['last_id']
+    # else:
+    #     last_id = 0
 
     etld_lib_functions.logger.info(f"Begin {api_call_name}")
     qualys_headers_dict = {}
@@ -101,13 +106,17 @@ def get_was_data(_: dict):
     cred_dict = _['cred_dict']
     page_size = _['page_size']
     dir_search_glob = _['dir_search_glob']
+    if 'last_id' in _.keys():
+        last_id = _['last_id']
+    else:
+        last_id = 0
 
     etld_lib_config.remove_old_files(
         dir_path=etld_lib_config.was_extract_dir,
         dir_search_glob=dir_search_glob
     )
 
-    batch_info = {'hasMoreRecords': 'true', 'lastId': 0}
+    batch_info = {'hasMoreRecords': 'true', 'lastId': last_id}
     has_more_records = 'true'
     batch_number = 0
     qualys_headers_dict = {}
@@ -163,7 +172,7 @@ def test_system_option(file_path: Path, has_more_records, number_of_files_to_ext
 def extract_was_api_data():
     begin_was_03_extract_controller()
     utc_datetime = etld_lib_datetime.get_utc_datetime_qualys_format()
-    cred_dict = etld_lib_credentials.get_cred(cred_dict={})
+    cred_dict = etld_lib_authentication_objects.qualys_authentication_obj.get_credentials_dict()
     etld_lib_config.remove_old_files(
         dir_path=etld_lib_config.was_extract_dir,
         dir_search_glob=etld_lib_config.was_extract_dir_file_search_blob,
@@ -185,21 +194,11 @@ def extract_was_api_data():
         name='was_count_webapp',
         args=(was_count_webapp_arg_dict,)
     )
-    # was_count_finding_arg_dict = {
-    #     'api_call_name': 'was_count_finding',
-    #     'was_extract_function_reference': was_04_extract_from_qualys.was_finding_extract_count,
-    #     'utc_datetime': utc_datetime, 'cred_dict': cred_dict,
-    #     'dir_search_glob': etld_lib_config.was_extract_dir_file_search_blob_finding_count
-    # }
-    # was_count_finding_proc = multiprocessing.Process(
-    #     target=get_was_count,
-    #     name='was_count_finding',
-    #     args=(was_count_finding_arg_dict,)
-    # )
     was_count_catalog_arg_dict = {
         'api_call_name': 'was_count_catalog',
         'was_extract_function_reference': was_04_extract_from_qualys.was_catalog_extract_count,
         'utc_datetime': utc_datetime, 'cred_dict': cred_dict,
+        'last_id': etld_lib_config.was_catalog_start_greater_than_last_id,
         'dir_search_glob': etld_lib_config.was_extract_dir_file_search_blob_catalog_count
     }
     was_count_catalog_proc = multiprocessing.Process(
@@ -220,21 +219,11 @@ def extract_was_api_data():
         args=(was_webapp_arg_dict,)
     )
 
-    # was_finding_arg_dict = {
-    #     'api_call_name': 'was_finding',
-    #     'was_extract_function_reference': was_04_extract_from_qualys.was_finding_extract,
-    #     'utc_datetime': utc_datetime, 'cred_dict': cred_dict, 'page_size': 300,
-    #     'dir_search_glob': etld_lib_config.was_extract_dir_file_search_blob_finding
-    # }
-    # was_finding_proc = multiprocessing.Process(
-    #     target=get_was_data,
-    #     name='was_finding',
-    #     args=(was_finding_arg_dict,)
-    # )
     was_catalog_arg_dict = {
         'api_call_name': 'was_catalog',
         'was_extract_function_reference': was_04_extract_from_qualys.was_catalog_extract,
         'utc_datetime': utc_datetime, 'cred_dict': cred_dict, 'page_size': 300,
+        'last_id': etld_lib_config.was_catalog_start_greater_than_last_id,
         'dir_search_glob': etld_lib_config.was_extract_dir_file_search_blob_catalog
     }
     was_catalog_proc = multiprocessing.Process(
@@ -243,14 +232,6 @@ def extract_was_api_data():
         args=(was_catalog_arg_dict,)
     )
 
-    # proc_list = [
-    #     was_count_webapp_proc,
-    #     was_count_finding_proc,
-    #     was_count_catalog_proc,
-    #     was_finding_proc,
-    #     was_webapp_proc,
-    #     was_catalog_proc
-    # ]
     proc_list = [
         was_count_webapp_proc,
         was_count_catalog_proc,
@@ -289,4 +270,5 @@ if __name__ == "__main__":
     etld_lib_functions.main(my_logger_prog_name='was_03_extract_controller')
     etld_lib_config.main()
     etld_lib_credentials.main()
+    etld_lib_authentication_objects.main()
     main()
