@@ -3,14 +3,15 @@ from pathlib import Path
 import json
 import gzip
 import re
-from qualys_etl.etld_lib import etld_lib_credentials as etld_lib_credentials
-from qualys_etl.etld_lib import etld_lib_config as etld_lib_config
-from qualys_etl.etld_lib import etld_lib_functions as etld_lib_functions
-from qualys_etl.etld_lib import etld_lib_extract_transform_load as etld_lib_extract_transform_load_distribute
+from qualys_etl.etld_lib import etld_lib_credentials
+from qualys_etl.etld_lib import etld_lib_authentication_objects
+from qualys_etl.etld_lib import etld_lib_config
+from qualys_etl.etld_lib import etld_lib_functions
+from qualys_etl.etld_lib import etld_lib_extract_transform_load as etld_lib_extract_transform_load
 
 
-def was_webapp_extract(batch_number_str, qualys_headers_dict, cred_dict, file_info_dict,
-                       last_id=0, page_size=25):
+def was_webapp_extract(
+        batch_number_str, qualys_headers_dict, cred_dict, file_info_dict, last_id=0, page_size=25):
 
     start_msg_was_extract(function_name='was_webapp_extract')
 
@@ -48,7 +49,7 @@ def was_webapp_extract(batch_number_str, qualys_headers_dict, cred_dict, file_in
     etld_lib_functions.logger.info(f"api call     - URL:{url} - PAYLOAD:{payload}")
     json_file = Path(file_info_dict['next_file_path'])
 
-    etld_lib_extract_transform_load_distribute.extract_qualys(
+    etld_lib_extract_transform_load.extract_qualys(
         try_extract_max_count=etld_lib_config.was_try_extract_max_count,
         url=url,
         headers=headers,
@@ -67,7 +68,8 @@ def was_webapp_extract(batch_number_str, qualys_headers_dict, cred_dict, file_in
         batch_number_str, qualys_headers_dict, cred_dict, file_info_dict, last_id=0, page_size=25)
 
 
-def was_webapp_detail_extract_controller(batch_number_str, qualys_headers_dict, cred_dict, file_info_dict, last_id=0, page_size=25):
+def was_webapp_detail_extract_controller(
+        batch_number_str, qualys_headers_dict, cred_dict, file_info_dict, last_id=0, page_size=25):
     # was_webapp_utc_run_datetime_2022-11-01T21:50:59Z_utc_last_scan_date_2022-10-25T00:00:00Z_batch_000001.json.gz
     # was_webapp_detail_utc_run_datetime_2022-11-01T21:50:59Z_utc_last_scan_date_2022-10-25T00:00:00Z_batch_000001_id_[idnum].json.gz
 
@@ -107,7 +109,8 @@ def was_webapp_detail_extract_controller(batch_number_str, qualys_headers_dict,
     end_msg_was_extract(function_name=f'was_webapp_detail_extract_batch_{batch_number_str}')
 
 
-def was_webapp_detail_extract_data_for_webapp_id(batch_number_str, qualys_headers_dict, cred_dict, file_info_dict, webapp_id=0):
+def was_webapp_detail_extract_data_for_webapp_id(
+        batch_number_str, qualys_headers_dict, cred_dict, file_info_dict, webapp_id=0):
 
     json_file = file_info_dict['webapp_id_detail_json_file']
 
@@ -122,7 +125,7 @@ def was_webapp_detail_extract_data_for_webapp_id(batch_number_str, qualys_header
     start_msg_was_extract(function_name=f'was_webapp_detail_extract_{batch_number_str}')
     etld_lib_functions.logger.info(f"api call     - URL:{url} - PAYLOAD:{payload}")
 
-    etld_lib_extract_transform_load_distribute.extract_qualys(
+    etld_lib_extract_transform_load.extract_qualys(
         try_extract_max_count=etld_lib_config.was_try_extract_max_count,
         url=url,
         headers=headers,
@@ -163,7 +166,7 @@ def was_finding_detail_extract_data_for_webapp_id(
 
     etld_lib_functions.logger.info(f"api call     - URL:{url} - PAYLOAD:{payload}")
 
-    etld_lib_extract_transform_load_distribute.extract_qualys(
+    etld_lib_extract_transform_load.extract_qualys(
         try_extract_max_count=etld_lib_config.was_try_extract_max_count,
         url=url,
         headers=headers,
@@ -177,111 +180,33 @@ def was_finding_detail_extract_data_for_webapp_id(
         extract_validation_type='json',
         compression_method=etld_lib_config.was_open_file_compression_method)
 
-    json_file = Path(file_info_dict['next_file_path'])
+    # NOT THIS ONE - json_file = Path(file_info_dict['next_file_path'])
     with etld_lib_config.was_open_file_compression_method(str(json_file), "rt", encoding='utf-8')  as read_file:
         json_data = json.load(read_file)
         if 'ServiceResponse' in json_data:
             if 'hasMoreRecords' in json_data['ServiceResponse']:
                 if str(json_data['ServiceResponse']['hasMoreRecords']).lower() == 'true':
-                    etld_lib_functions.logger.error(f"Found webapp_id: {batch_number_str} has more than 1000 findings")
+                    etld_lib_functions.logger.error(f"Found webapp_id: {batch_number_str} has more than page_size: {page_size} findings")
                     etld_lib_functions.logger.error(f"File: {str(json_file)}")
                     etld_lib_functions.logger.error(f"Contact your Qualys TAM to discuss solution with David Gregory.")
-                    exit(1)
+                    #exit(1) - do not exit, instead report error to logs and move forward.
+                    # let validate log check will catch this error.
     end_msg_was_extract(function_name=f'was_finding_detail_extract_{batch_number_str}')
 
 
-# def was_finding_extract(batch_number_str, qualys_headers_dict, cred_dict, file_info_dict,
-#                         last_id=0, page_size=25):
-#
-#     start_msg_was_extract(function_name='was_finding_extract')
-#     payload = '{"ServiceRequest": {' \
-#               '"preferences": {"limitResults": ' \
-#               f'"{page_size}"' \
-#               ', "verbose": "true"}, ' \
-#               '"filters": {' '"Criteria": ' \
-#               '[{"field": "id", "operator": "GREATER", "value": ' \
-#               f'"{last_id}"' + '}]}}}'
-#
-#     # TODO determine if customer needs iteration.  Until then, pull all findings.
-#     # TODO iterate through webApp.id list pulling all findings for each webApp.id
-#     # payload_template = '{"ServiceRequest": {"preferences": {"limitResults": "300", "verbose": "true"}, ' \
-#     #                    '"filters": {"Criteria": [{"field": "id", "operator": "GREATER", "value": "0"}]}}}'
-#     # payload_dict = json.loads(payload_template)
-#     # payload_filter = payload_dict['ServiceRequest']['filters']['Criteria']
-#     # payload_filter.append({'field': 'name', 'operator': '', 'value': 0})
-#
-#     url = f"https://{cred_dict['api_fqdn_server']}/qps/rest/3.0/search/was/finding"
-#     headers = {'X-Requested-With': 'qualysetl',
-#                'Authorization': cred_dict['authorization'],
-#                'Content-Type': 'application/json',
-#                'Accept': 'application/json',
-#                }
-#
-#     etld_lib_functions.logger.info(f"api call     - URL:{url} - PAYLOAD:{payload}")
-#     json_file = Path(file_info_dict['next_file_path'])
-#
-#     etld_lib_extract_transform_load_distribute.extract_qualys(
-#         try_extract_max_count=etld_lib_config.was_try_extract_max_count,
-#         url=url,
-#         headers=headers,
-#         payload=payload,
-#         http_conn_timeout=etld_lib_config.was_http_conn_timeout,
-#         chunk_size_calc=etld_lib_config.was_chunk_size_calc,
-#         output_file=json_file,
-#         cred_dict=cred_dict,
-#         qualys_headers_multiprocessing_dict=qualys_headers_dict,
-#         batch_number_formatted=batch_number_str,
-#         extract_validation_type='json',
-#         compression_method=etld_lib_config.was_open_file_compression_method)
-#     end_msg_was_extract(function_name='was_finding_extract')
-
-
-# def was_detail_extract(
-#         batch_number_str, qualys_headers_dict, cred_dict, file_info_dict, item_id, api_type='Finding'):
-#
-#     json_file = str(file_info_dict['next_file_path']).replace(".json", f"_id_{item_id}.json")
-#     json_file = json_file.replace("_utc_", "_detail_utc_")
-#     url = f"https://{cred_dict['api_fqdn_server']}/qps/rest/3.0/get/was/{api_type.lower()}/{item_id}"
-#
-#     start_msg_was_extract(function_name='was_detail_extract')
-#     payload = {}
-#
-#     headers = {'X-Requested-With': 'qualysetl',
-#                'Authorization': cred_dict['authorization'],
-#                'Content-Type': 'application/json',
-#                'Accept': 'application/json',
-#                }
-#
-#     etld_lib_functions.logger.info(f"api call     - URL:{url} ")
-#     etld_lib_extract_transform_load_distribute.extract_qualys(
-#         try_extract_max_count=etld_lib_config.was_try_extract_max_count,
-#         url=url,
-#         headers=headers,
-#         payload=payload,
-#         http_conn_timeout=etld_lib_config.was_http_conn_timeout,
-#         chunk_size_calc=etld_lib_config.was_chunk_size_calc,
-#         output_file=json_file,
-#         cred_dict=cred_dict,
-#         qualys_headers_multiprocessing_dict=qualys_headers_dict,
-#         batch_number_formatted=batch_number_str,
-#         extract_validation_type='json',
-#         compression_method=etld_lib_config.was_open_file_compression_method,
-#         request_method="GET"
-#         )
-#     end_msg_was_extract(function_name='was_detail_extract')
-
-
-def was_catalog_extract(batch_number_str, qualys_headers_dict, cred_dict, file_info_dict,
-                        last_id=0, page_size=25):
+def was_catalog_extract(
+        batch_number_str, qualys_headers_dict, cred_dict, file_info_dict, last_id=0, page_size=25):
 
     start_msg_was_extract(function_name='was_catalog_extract')
+    filter_field = 'id'
+    filter_operator = 'GREATER'
+    filter_value = last_id
     payload = '{"ServiceRequest": {' \
-              '"preferences": {"limitResults": ' \
-              f'"{page_size}"' \
-              ', "verbose": "true"}, ' \
-              '"filters": {' '"Criteria": ' \
-              '{"field": "id", "operator": "GREATER", "value": ' \
-              f'"{last_id}"' + '}}}}'
+              '"preferences": {"limitResults": ' f'"{page_size}"'  ', "verbose": "true"}, ' \
+              '"filters": {' '"Criteria":  ' \
+              '{"field": ' f'"{filter_field}"' ', "operator": ' f'"{filter_operator}"' ', "value": ' f'"{filter_value}"' '}' \
+              '}' \
+              '}}'
 
     url = f"https://{cred_dict['api_fqdn_server']}/qps/rest/3.0/search/was/catalog"
     headers = {'X-Requested-With': 'qualysetl',
@@ -293,7 +218,7 @@ def was_catalog_extract(batch_number_str, qualys_headers_dict, cred_dict, file_i
     etld_lib_functions.logger.info(f"api call     - URL:{url} - PAYLOAD:{payload}")
     json_file = Path(file_info_dict['next_file_path'])
 
-    etld_lib_extract_transform_load_distribute.extract_qualys(
+    etld_lib_extract_transform_load.extract_qualys(
         try_extract_max_count=etld_lib_config.was_try_extract_max_count,
         url=url,
         headers=headers,
@@ -337,7 +262,7 @@ def was_webapp_extract_count(batch_number_str, qualys_headers_dict, cred_dict, f
     etld_lib_functions.logger.info(f"api call     - {url}")
     json_file = Path(file_info_dict['next_file_path'])
 
-    etld_lib_extract_transform_load_distribute.extract_qualys(
+    etld_lib_extract_transform_load.extract_qualys(
         try_extract_max_count=etld_lib_config.was_try_extract_max_count,
         url=url,
         headers=headers,
@@ -367,7 +292,7 @@ def was_finding_extract_count(batch_number_str, qualys_headers_dict, cred_dict,
 
     json_file = Path(file_info_dict['next_file_path'])
 
-    etld_lib_extract_transform_load_distribute.extract_qualys(
+    etld_lib_extract_transform_load.extract_qualys(
         try_extract_max_count=etld_lib_config.was_try_extract_max_count,
         url=url,
         headers=headers,
@@ -393,14 +318,29 @@ def was_catalog_extract_count(batch_number_str, qualys_headers_dict, cred_dict,
                'Accept': 'application/json',
                }
 
-    etld_lib_functions.logger.info(f"api call     - {url}")
+    payload = '{"ServiceRequest": {' \
+              '"filters": {' '"Criteria": [' \
+              '{"field": "id", "operator": ' \
+              '"GREATER", "value": '  f'"{etld_lib_config.was_catalog_start_greater_than_last_id}"' + '}' \
+                  ']}}}'
+
+    filter_field = 'id'
+    filter_operator = 'GREATER'
+    filter_value = etld_lib_config.was_catalog_start_greater_than_last_id
+    payload = '{"ServiceRequest": {' \
+              '"filters": {' '"Criteria":  ' \
+              '{"field": ' f'"{filter_field}"' ', "operator": ' f'"{filter_operator}"' ', "value": ' f'"{filter_value}"' '}' \
+              '}' \
+              '}}'
+
+    etld_lib_functions.logger.info(f"api call     - URL:{url} - PAYLOAD:{payload}")
     json_file = Path(file_info_dict['next_file_path'])
 
-    etld_lib_extract_transform_load_distribute.extract_qualys(
+    etld_lib_extract_transform_load.extract_qualys(
         try_extract_max_count=etld_lib_config.was_try_extract_max_count,
         url=url,
         headers=headers,
-        payload={},
+        payload=payload,
         http_conn_timeout=etld_lib_config.was_http_conn_timeout,
         chunk_size_calc=etld_lib_config.was_chunk_size_calc,
         output_file=json_file,
@@ -455,6 +395,7 @@ if __name__ == "__main__":
     etld_lib_functions.main(my_logger_prog_name='was_04_extract_from_qualys')
     etld_lib_config.main()
     etld_lib_credentials.main()
+    etld_lib_authentication_objects.main()
     main()
 
 
