@@ -414,12 +414,28 @@ def transform_and_load_all_json_files_into_sqlite(dir_file_search_blob=None):
                         status_column='begin')
 
                 json_data = json.load(read_file)
+
+                json_success_found = False
+                if 'ServiceResponse' in json_data:
+                    if 'responseCode' in json_data['ServiceResponse']:
+                        responseCode = json_data['ServiceResponse']['responseCode']
+                        if 'success' == str(responseCode).lower():
+                            json_success_found = True
+
+                if json_success_found:
+                    pass
+                else:
+                    etld_lib_functions.logger.error(
+                        f"C1 - Found invalid batch json with no responseCode SUCCESS: {status_name_column} - {batch_name}")
+                    json_data_string = str(json.dumps(json_data)).replace('\n', ' ').replace('\r', ' ')
+                    etld_lib_functions.logger.error(f"JSON DATA: {json_data_string}")
+                    etld_lib_functions.logger.error(f"json_file: {json_file}")
+                    exit(1)
+
                 if 'data' in json_data['ServiceResponse']:
                     for data_list_item in json_data['ServiceResponse']['data']:
                         insert_one_row_into_was_table(data_list_item, sqlite_was, counter_objects, batch_name, batch_date, batch_number)
                     sqlite_was.commit_changes()
-                    # TODO DISTRIBUTE AS "CSV, PARQUET, ETC" CREATE BATCH HERE.
-
                     etld_lib_functions.logger.info(
                         f"Added batch file from directory into Database: {status_name_column} - {batch_name}")
 
@@ -432,16 +448,17 @@ def transform_and_load_all_json_files_into_sqlite(dir_file_search_blob=None):
                             status_table_column_types=etld_lib_config.status_table_csv_column_types(),
                             status_name_column=status_name_column,
                             status_column='end')
-                elif 'responseCode' in json_data['ServiceResponse']:
-                    if 'success' in str(json_data['ServiceResponse']['responseCode']).lower():
-                       etld_lib_functions.logger.info(
-                           f"Skipping, No Data in batch file from directory into Database: {status_name_column} - {batch_name}")
-                    else:
-                        etld_lib_functions.logger.error(
-                            f"Found invalid batch json with no responseCode SUCCESS: {status_name_column} - {batch_name}")
-                        etld_lib_functions.logger.error(
-                            f"json_file: {json_file}")
-                        exit(1)
+                elif 'success' in str(json_data['ServiceResponse']['responseCode']).lower():
+                    etld_lib_functions.logger.info(
+                        f"Skipping, No Data in batch file from directory into "
+                        f"Database: {status_name_column} - {batch_name}")
+                else:
+                    etld_lib_functions.logger.error(
+                        f"C2 - Found invalid batch json with no responseCode SUCCESS: {status_name_column} - {batch_name}")
+                    json_data_string = str(json.dumps(json_data)).replace('\n', ' ').replace('\r', ' ')
+                    etld_lib_functions.logger.error(f"JSON DATA: {json_data_string}")
+                    etld_lib_functions.logger.error(f"json_file: {json_file}")
+                    exit(1)
 
         create_kb_table_in_was_database(sqlite_obj=sqlite_was)
         sqlite_was.update_status_table(
