@@ -11,10 +11,11 @@ import getpass
 import json
 from pathlib import Path
 import qualys_etl
-import qualys_etl.etld_lib.etld_lib_functions as etld_lib_functions
-import qualys_etl.etld_lib.etld_lib_config as etld_lib_config
-import qualys_etl.etld_lib.etld_lib_credentials as etld_lib_credentials
-import qualys_etl.etld_lib.etld_lib_datetime as api_datetime
+from qualys_etl.etld_lib import etld_lib_functions
+from qualys_etl.etld_lib import etld_lib_config
+from qualys_etl.etld_lib import etld_lib_credentials
+from qualys_etl.etld_lib import etld_lib_authentication_objects
+from qualys_etl.etld_lib import etld_lib_datetime
 
 global qetl_user_home
 global found_api_credentials
@@ -56,7 +57,7 @@ def validate_password(password):
 def update_api_fqdn_server(cred):
     print(f"Current api_fqdn_server: {cred.get('api_fqdn_server')}")
     response = input(f"Update api_fqdn_server? ( yes or no ): ")
-    if response in 'yes':
+    if response == 'yes':
         while True:
             new_api_fqdn_server = input(f"Enter new api_fqdn_server: ")
             new_api_fqdn_server = re.sub("https://", '', new_api_fqdn_server)
@@ -71,12 +72,31 @@ def update_api_fqdn_server(cred):
 
 
 def update_gateway_fqdn_server(cred):
+    #
     if cred.get('api_fqdn_server') in etld_lib_credentials.platform_url.keys():
         cred['gateway_fqdn_server'] = etld_lib_credentials.platform_url.get(cred.get('api_fqdn_server'))
 
     print(f"Current gateway_fqdn_server: {cred.get('gateway_fqdn_server')}")
     response = input(f"Update gateway_fqdn_server? ( yes or no ): ")
-    if response in 'yes':
+    if response == 'yes':
+        while True:
+            new_gateway_fqdn_server = input(f"Enter new gateway_fqdn_server: ")
+            new_gateway_fqdn_server = re.sub("https://", '', new_gateway_fqdn_server)
+            new_gateway_fqdn_server = re.sub("http://", '', new_gateway_fqdn_server)
+            new_gateway_fqdn_server = re.sub("/", '', new_gateway_fqdn_server)
+            if validate_gateway_fqdn_server(new_gateway_fqdn_server):
+                break
+            else:
+                print(f"Not valid gateway FQDN, retry.")
+        cred['gateway_fqdn_server'] = new_gateway_fqdn_server
+    pass
+
+
+def update_gateway_fqdn_server_from_etld_lib_authentication_objects(cred, authentication_obj: etld_lib_authentication_objects.QualysAuthenticationObj):
+    cred['gateway_fqdn_server'] = authentication_obj.get_gateway_platform_fqdn(cred['api_fqdn_server'])
+    print(f"Current gateway_fqdn_server: {cred.get('gateway_fqdn_server')}")
+    response = input(f"Update gateway_fqdn_server? ( yes or no ): ")
+    if response == 'yes':
         while True:
             new_gateway_fqdn_server = input(f"Enter new gateway_fqdn_server: ")
             new_gateway_fqdn_server = re.sub("https://", '', new_gateway_fqdn_server)
@@ -92,9 +112,9 @@ def update_gateway_fqdn_server(cred):
 
 def update_username(cred):
     time.sleep(1)
-    print(f"\n\nCurrent username: {cred.get('username')} in config: {etld_lib_credentials.cred_file}")
+    print(f"\n\nCurrent username: {cred.get('username')} in config: {etld_lib_config.qetl_user_cred_file}")
     response = input(f"Update Qualys username? ( yes or no ): ")
-    if response in 'yes':
+    if response == 'yes':
         while True:
             new_username = input(f"Enter new Qualys username: ")
             if validate_username(new_username):
@@ -108,7 +128,7 @@ def update_username(cred):
 def update_password(cred):
     print(f"Update password for username: {cred.get('username')}")
     response = input(f"Update password? ( yes or no ): ")
-    if response in 'yes':
+    if response == 'yes':
         while True:
             new_password = getpass.getpass(f"Enter your Qualys password: ")
             if validate_password(new_password):
@@ -274,6 +294,46 @@ def if_user_selected_update_credentials_stored_on_disk(first_time=False):
         return False
 
 
+def if_user_selected_update_credentials_stored_on_disk_from_etld_lib_authentication_objects(first_time=False):
+    if command_line_arguments.credentials is not None or first_time is not False:
+        etld_lib_config.main()
+        etld_lib_authentication_objects.main_no_logger_for_qetl_manage_user(test_about_qualys_flag=False)
+        authentication_obj: etld_lib_authentication_objects.QualysAuthenticationObj \
+            = etld_lib_authentication_objects.qualys_authentication_obj
+        credentials = authentication_obj.get_credentials()
+        old_cred = authentication_obj.get_credentials()
+        # etld_lib_credentials.main()
+        # credentials = etld_lib_credentials.get_cred()
+        update_username(credentials)
+        update_api_fqdn_server(credentials)
+        update_gateway_fqdn_server_from_etld_lib_authentication_objects(credentials, authentication_obj)
+        update_password(credentials)
+        # old_cred = etld_lib_credentials.get_cred()
+        if old_cred == credentials:
+            print(f"No changes to qualys username, password, api_fqdn_server or gateway_fqdn_server.")
+        else:
+            authentication_obj.update_yaml_file_credentials(new_cred=credentials)
+            authentication_obj.set_credentials(force_from_file=True)
+            new_credentials = authentication_obj.get_credentials()
+            # etld_lib_credentials.update_cred(credentials)
+            # new_credentials = etld_lib_credentials.get_cred()
+            print(f"Credentials updated.  OLD: username: {old_cred.get('username')}, "
+                  f"api_fqdn_server: {old_cred.get('api_fqdn_server')}, "
+                  f"gateway_fqdn_server: {old_cred.get('gateway_fqdn_server')}, "
+                  f"")
+            print(f"Credentials updated.  NEW: username: {new_credentials.get('username')}, "
+                                           f"api_fqdn_server: {new_credentials.get('api_fqdn_server')}, "
+                                           f"gateway_fqdn_server: {new_credentials.get('gateway_fqdn_server')}, "
+                                           f"")
+            print(f"You have updated your credentials.")
+            print(f"  Qualys Username:            {new_credentials.get('username')}")
+            print(f"  Qualys api_fqdn_server:     {new_credentials.get('api_fqdn_server')}")
+            print(f"  Qualys gateway_fqdn_server: {new_credentials.get('gateway_fqdn_server')}\n")
+        return True
+    else:
+        return False
+
+
 def start_etl_knowledgebase():
     import qualys_etl.etld_knowledgebase.knowledgebase_01_spawn_workflow_manager as etl_kb_spawn_from_qetl_manage_user
     print(f"Starting etl_knowledgebase.  For progress see your {etld_lib_config.kb_log_file}")
@@ -342,7 +402,7 @@ def validate_and_set_command_line_arguments_datetime_in_etld_lib_config():
     if command_line_arguments.datetime is None:
         pass
     else:
-        if api_datetime.is_valid_qualys_datetime_format(command_line_arguments.datetime):
+        if etld_lib_datetime.is_valid_qualys_datetime_format(command_line_arguments.datetime):
             etld_lib_config.qetl_manage_user_selected_datetime = command_line_arguments.datetime
         else:
             print(f"\nInvalid datetime: {str(command_line_arguments.datetime)}, "
@@ -398,6 +458,38 @@ def if_user_selected_test_qualys_basic_authentication_login(first_time=False):
         return False
 
 
+def if_user_selected_test_qualys_basic_authentication_login_from_etld_lib_authentication_objects(first_time=False):
+    if command_line_arguments.test is not None or first_time is not False:
+        etld_lib_functions.main(log_level=logging.info, my_logger_prog_name='qetl_manage_user')
+        etld_lib_config.main()
+        #etld_lib_credentials.main()
+        #credentials = etld_lib_credentials.get_cred()
+        etld_lib_authentication_objects.main(test_about_qualys_flag=False)
+        credentials = etld_lib_authentication_objects.qualys_authentication_obj.get_credentials()
+
+        print(f"Qualys Login Test for {credentials.get('username')} "
+              f"at api_fqdn_server: {credentials.get('api_fqdn_server')}\n")
+        # login_status = etld_lib_credentials.test_qualys_login_logout_basic_auth()
+        login_status_flag = etld_lib_authentication_objects.qualys_authentication_obj.test_qualys_login_logout_basic_auth()
+        login_status = etld_lib_authentication_objects.qualys_authentication_obj.test_qualys_login_logout_basic_auth_result_dict
+        credentials_source = etld_lib_authentication_objects.qualys_authentication_obj.credentials_source
+        if login_status_flag is True:
+            print(f"Testing Qualys Login/Logout for {credentials.get('username')} "
+                  f"Succeeded at {credentials.get('api_fqdn_server')} with credentials_source: {credentials_source}\n"
+                  f"    with HTTPS Return Code: {login_status['response_status_code']}.")
+        else:
+            print(f"Testing Qualys Login/Logout for {credentials.get('username')} "
+                  f"Failed at {credentials.get('api_fqdn_server')} with credentials_source: {credentials_source}\n "
+                  f"    with HTTPS Return Code: {login_status['response_status_code']} \n"
+                  f"    Exception: {login_status['Exception']} \n"
+                  f"    Message:   {login_status['message']}")
+
+        etld_lib_functions.main(log_level=logging.WARN, my_logger_prog_name='qetl_manage_user')
+        return True
+    else:
+        return False
+
+
 # def if_user_selected_test_qualys_gateway_token_login(first_time=False):
 #     if command_line_arguments.test is not None or first_time is not False:
 #         etld_lib_functions.main(log_level=logging.INFO, my_logger_prog_name='qetl_manage_user')
@@ -627,11 +719,13 @@ def setup_qualys_etl_user_home_environment_in_memory_and_in_etld_lib_config():
             etld_lib_config.main()
             time.sleep(1)
             print(f"\nqetl_user_home_dir created: {etld_lib_config.qetl_user_home_dir}")
-            if_user_selected_update_credentials_stored_on_disk(first_time=True)
+            #if_user_selected_update_credentials_stored_on_disk(first_time=True)
+            if_user_selected_update_credentials_stored_on_disk_from_etld_lib_authentication_objects(first_time=True)
             response = input(f"\nWould you like to test login/logout of Qualys API? ( yes or no ): ")
             if response == 'yes':
                 print("")
-                if_user_selected_test_qualys_basic_authentication_login(first_time=True)
+                #if_user_selected_test_qualys_basic_authentication_login(first_time=True)
+                if_user_selected_test_qualys_basic_authentication_login_from_etld_lib_authentication_objects(first_time=True)
             print(f"\nThank you, exiting.\n")
             exit(0)
         elif response == 'qetl_manage_user_init':
@@ -667,10 +761,13 @@ def main():
         pass
     elif if_user_selected_setting_credentials_in_memory():
         pass
-    elif if_user_selected_update_credentials_stored_on_disk():
+    elif if_user_selected_update_credentials_stored_on_disk_from_etld_lib_authentication_objects():
         pass
+    #elif if_user_selected_update_credentials_stored_on_disk():
+    #    pass
 
-    if_user_selected_test_qualys_basic_authentication_login()
+    #if_user_selected_test_qualys_basic_authentication_login()
+    if_user_selected_test_qualys_basic_authentication_login_from_etld_lib_authentication_objects()
 
     if if_user_selected_print_directory_listing_report():
         pass
